@@ -12,7 +12,7 @@ use std::io;
 pub mod persistent;
 
 #[cfg(feature = "impls")]
-mod impls {
+pub mod impls {
     pub mod option_log;
     pub use option_log::*;
     pub mod result_log;
@@ -22,8 +22,17 @@ mod impls {
 #[cfg(test)]
 pub mod test;
 
-pub fn log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &str, msg: T) -> io::Result<()> {
-    print_log(#[cfg(feature = "colored")] color, prefix, &msg)?;
+pub fn log<T: AsRef<str>>(
+    #[cfg(feature = "colored")] color: Color,
+    prefix: &str,
+    msg: T,
+) -> io::Result<()> {
+    print_log(
+        #[cfg(feature = "colored")]
+        color,
+        prefix,
+        &msg,
+    )?;
 
     #[cfg(feature = "persistent")]
     if persistent::check_env() {
@@ -32,9 +41,13 @@ pub fn log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &str
     Ok(())
 }
 
-fn print_log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &str, msg: &T) -> io::Result<()> {
-    #[cfg(feature = "colored")] 
-    return execute!(
+#[cfg(feature = "colored")]
+fn print_log<T: AsRef<str>>(
+    #[cfg(feature = "colored")] color: Color,
+    prefix: &str,
+    msg: &T,
+) -> io::Result<()> {
+    execute!(
         io::stderr().lock(),
         Print("["),
         SetAttribute(Attribute::Bold),
@@ -44,12 +57,11 @@ fn print_log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &s
         Print("]: "),
         Print(msg.as_ref()),
         Print('\n')
-    );
-    
-    #[cfg(not(feature = "colored"))]
-    {
-        use std::io::Write;
-        writeln!(io::stderr().lock(), "[ {prefix} ]: {}", msg.as_ref())
-            .map(|_| ())
-    }
+    )
+}
+
+#[cfg(not(feature = "colored"))]
+fn print_log<T: AsRef<str>>(prefix: &str, msg: T) -> io::Result<()> {
+    use std::io::Write;
+    writeln!(io::stderr().lock(), "[{prefix}]: {}", msg.as_ref()).map(|_| ())
 }
